translate.misc.diff_match_patch.patch_obj

Package translate :: Package misc :: Module diff_match_patch :: Class patch_obj |
[hide private]
[frames] | no frames]

# Class patch_obj

source code

Class representing one patch operation.

Instance Methods | [hide private]
__init__(self) Initializes with an empty list of diffs. | source code
__str__(self) Emmulate GNU diff's format. | source code

Method Details | [hide private]

### __str__(self) (Informal representation operator) | source code
    Emmulate GNU diff's format.
    Header: @@ -382,8 +481,9 @@
    Indicies are printed as 1-based, not 0-based.

    Returns:
      The GNU diff string.